@@ -80,8 +80,10 @@ from .quadrature import (
 )
 from .mesh import (
     Mesh,
+    MeshContainer,
     Rectangle,
     Cube,
+    Grid,
 )
 from .constitution import (
     NeoHooke,
@@ -101,6 +103,8 @@ from .tools import (
 )
 from .mechanics import (
     SolidBody,
+    SolidBodyNearlyIncompressible,
+    StateNearlyIncompressible,
     SolidBodyPressure,
     SolidBodyTensor,
     SolidBodyGravity,
