@@ -130,7 +130,7 @@ def planar(field, right=1, move=0.2, clamped=False):
     return bounds, dict(dof0=dof0, dof1=dof1, ext0=ext0)
 
 
-def shear(field, bottom=0, top=1, move=0.2, sym=True):
+def shear(field, bottom=0, top=1, move=0.2, compression=0.0, sym=True):
     """Define boundaries for shear loading between two clamped plates. The
     bottom plate remains fixed while the shear is applied at the top plate."""
 
@@ -141,7 +141,8 @@ def shear(field, bottom=0, top=1, move=0.2, sym=True):
     else:
         bounds = {}
 
-    bounds["bottom"] = Boundary(f, fy=bottom)
+    bounds["bottom"] = Boundary(f, fy=bottom, skip=(0, 1, 0))
+    bounds["compression"] = Boundary(f, fy=bottom, skip=(1, 0, 1), value=compression)
     bounds["top"] = Boundary(f, fy=top, skip=(1, 0, 0))
     bounds["move"] = Boundary(f, fy=top, skip=(0, 1, 1), value=move)
 
