@@ -46,7 +46,8 @@ def test_math_field():
     fe.math.interpolate(u)
     fe.math.grad(u)
     fe.math.grad(u, sym=True)
-    fe.math.tovoigt(fe.math.strain(u))
+    fe.math.tovoigt(fe.math.strain(u), strain=False)
+    fe.math.tovoigt(fe.math.strain(u), strain=True)
     fe.math.strain(u)
     fe.math.extract(u)
     fe.math.extract(u, grad=False)
